# Meaning Eraser

A simple program that can erase the meaning of your life.

## Installation

This program is only for Linux.

To install it run `pip install meaning-eraser`

## Usage

To erase the meaning of your life run `python -m meaning.py`
